from pathlib import Path
from tools import file_writer
import numpy as np
from typing import List, Tuple
import shap

def get_shap_tree_explainer(model, X_train=None, X_test=None) -> Tuple[shap.TreeExplainer,
                                                                     np.ndarray]:
    explainer = shap.TreeExplainer(model, data=X_train)
    shap_values = explainer.shap_values(X_test)
    return explainer, shap_values

def get_shap_deep_explainer(model, X_train, X_test) -> Tuple[shap.DeepExplainer,
                                                             np.ndarray]:
    explainer = shap.DeepExplainer(model, X_train)
    shap_values = explainer.shap_values(X_test)
    return explainer, shap_values

def make_shap_summary_plot(shap_values, X_test, cols, file_name, path, plot_type) -> None:
    file_writer.write_shap_summary_plot(shap_values, X_test, cols, file_name, path, plot_type)

def explain_shap_instance(expected_value: float,
                          shap_value: np.ndarray,
                          row: np.ndarray,
                          cols: List[str],
                          file_name: str,
                          path: Path) -> None:
    file_writer.write_shap_explanation(expected_value,
                                       shap_value,
                                       row,
                                       cols,
                                       file_name,
                                       path)