from pathlib import Path
import pandas as pd
from typing import List
import numpy as np
import joblib
import pickle
import csv

def read_embedding(path: Path, filename: str):
    with open(Path.joinpath(path, filename), 'r') as f:
        reader = csv.reader(f)
        embedding_dict = {rows[0]:rows[1] for rows in reader}
    return embedding_dict
    
def read_array(path: Path, filename: str) -> np.ndarray:
    return np.load(Path.joinpath(path, filename))

def read_pickle(path: Path, filename: str) -> any:
    with open(Path.joinpath(path, filename), 'rb') as f:
        data = pickle.load(f)
    return data

def read_joblib(path: Path, filename: str) -> any:
    return joblib.load(Path.joinpath(path, filename))
    
def read_csv(path: Path, filename: str, header: str='infer',
             sep: str=',', names: List[str]=None, converters: dict=None) -> pd.DataFrame:
    return pd.read_csv(Path.joinpath(path, filename), header=header,
                       sep=sep, names=names, converters=converters)

def read_excelfile(path: Path, filename: str, converters: dict=None) -> pd.DataFrame:
    df = pd.read_excel(Path.joinpath(path, filename),
                       engine='openpyxl',
                       converters=converters)
    return df

def read_excelfile_sheets(path: Path, filename: str, n_sheets: int,
                          converters: dict=None) -> pd.DataFrame:
    file = pd.ExcelFile(Path.joinpath(path, filename), engine='openpyxl')
    full_file = pd.DataFrame()
    for i in range(n_sheets):
        df = file.parse(file.sheet_names[i], converters=converters)
        full_file = pd.concat([full_file, df])
    return full_file