import pandas as pd
import datetime
from tools.cleaner import Cleaner2020

def test_filter_ats_on_ids():
    df = pd.DataFrame([i for i in range(10)], columns=['CitizenId'])
    ids = [i for i in range(5)]
    filtered_list = Cleaner2020().filter_ats_on_ids(df, ids)
    assert not filtered_list.empty
    assert len(filtered_list) == 5

def test_sort_dataframe():
    today = datetime.date.today()
    yesterday = today - datetime.timedelta(days=1)
    df = pd.DataFrame({
        'CitizenId': [42,41],
        'RatingDate': [yesterday, today]})
    res = Cleaner2020().sort_dataframe(df, ['CitizenId', 'RatingDate'])
    assert not res.empty
    assert res.iloc[0]['CitizenId'] == 41
    assert res.iloc[0]['RatingDate'] == today

def test_merge_train_and_patient_data():
    df1 = pd.DataFrame({
        'PatientId': [1, 2, 3],
        'RatingScore': [37, 38, 39]})
    df2 = pd.DataFrame({
        'PatientId': [3, 2, 1],
        'RatingScore': [59, 60, 61]})
    res = Cleaner2020().merge_train_and_patient_data(df1, df2, 'PatientId')
    assert not res.empty
    pd.testing.assert_series_equal(res['PatientId'], df1['PatientId'])

def test_remove_citizens_without_valid_id():
    df = pd.DataFrame({
        'CitizenId': ['0', '0', '37'],
        'PatientId': [1, 2, 3]})
    res = Cleaner2020().remove_citizens_without_valid_id(df)
    assert not res.empty
    assert len(res) == 1

def test_remove_citizens_not_in_patient_data():
    df_train = pd.DataFrame({'PatientId': [1, 2, 3]})
    df_patient = pd.DataFrame({'PatientId': [1]})
    res = Cleaner2020().remove_citizens_not_in_patient_data(
        df_train, df_patient, 'PatientId')
    assert not res.empty
    assert len(res) == 1

def test_remove_tainted_histories():
    df = pd.DataFrame({
        'DevHMINumber': ['899,997', '899,989', '899,999'],
        'CitizenId': [1, 2, 3]})
    res = Cleaner2020().remove_tainted_histories(df)
    assert not res.empty
    assert res.shape == (2,2)

def test_remove_deprecated_device_data():
    df = pd.DataFrame({'DevHMINumber': ['899,997', '899,989', '899,999']})
    res = Cleaner2020().remove_deprecated_device_data(df)
    assert not res.empty
    assert len(res) == 2

def test_remove_rows_with_old_dates():
    df = pd.DataFrame({'LendDate': ['1899-02-02', '1900-01-01', '2020-05-27']})
    res = Cleaner2020().remove_rows_with_old_dates(df, 'LendDate')
    assert not res.empty
    assert len(res) == 2